==> knative-model-6.2.0-sources.jar: io/fabric8/knative/sources/v1/SinkBindingListFluent.java <==
package io.fabric8.knative.sources.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface SinkBindingListFluent<A extends SinkBindingListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,SinkBinding item);
  public A setToItems(Integer index,SinkBinding item);
  public A addToItems(io.fabric8.knative.sources.v1.SinkBinding... items);
  public A addAllToItems(Collection<SinkBinding> items);
  public A removeFromItems(io.fabric8.knative.sources.v1.SinkBinding... items);
  public A removeAllFromItems(Collection<SinkBinding> items);
  public A removeMatchingFromItems(Predicate<SinkBindingBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<SinkBinding> getItems();
  public List<SinkBinding> buildItems();
  public SinkBinding buildItem(Integer index);
  public SinkBinding buildFirstItem();
  public SinkBinding buildLastItem();
  public SinkBinding buildMatchingItem(Predicate<SinkBindingBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<SinkBindingBuilder> predicate);
  public A withItems(List<SinkBinding> items);
  public A withItems(io.fabric8.knative.sources.v1.SinkBinding... items);
  public Boolean hasItems();
  public SinkBindingListFluent.ItemsNested<A> addNewItem();
  public SinkBindingListFluent.ItemsNested<A> addNewItemLike(SinkBinding item);
  public SinkBindingListFluent.ItemsNested<A> setNewItemLike(Integer index,SinkBinding item);
  public SinkBindingListFluent.ItemsNested<A> editItem(Integer index);
  public SinkBindingListFluent.ItemsNested<A> editFirstItem();
  public SinkBindingListFluent.ItemsNested<A> editLastItem();
  public SinkBindingListFluent.ItemsNested<A> editMatchingItem(Predicate<SinkBindingBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,SinkBindingFluent<SinkBindingListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> knative-model-6.7.1-sources.jar: io/fabric8/knative/sources/v1/SinkBindingListFluent.java <==
package io.fabric8.knative.sources.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface SinkBindingListFluent<A extends SinkBindingListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,SinkBinding item);
  public A setToItems(int index,SinkBinding item);
  public A addToItems(io.fabric8.knative.sources.v1.SinkBinding... items);
  public A addAllToItems(Collection<SinkBinding> items);
  public A removeFromItems(io.fabric8.knative.sources.v1.SinkBinding... items);
  public A removeAllFromItems(Collection<SinkBinding> items);
  public A removeMatchingFromItems(Predicate<SinkBindingBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<SinkBinding> getItems();
  public List<SinkBinding> buildItems();
  public SinkBinding buildItem(int index);
  public SinkBinding buildFirstItem();
  public SinkBinding buildLastItem();
  public SinkBinding buildMatchingItem(Predicate<SinkBindingBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<SinkBindingBuilder> predicate);
  public A withItems(List<SinkBinding> items);
  public A withItems(io.fabric8.knative.sources.v1.SinkBinding... items);
  public Boolean hasItems();
  public SinkBindingListFluent.ItemsNested<A> addNewItem();
  public SinkBindingListFluent.ItemsNested<A> addNewItemLike(SinkBinding item);
  public SinkBindingListFluent.ItemsNested<A> setNewItemLike(int index,SinkBinding item);
  public SinkBindingListFluent.ItemsNested<A> editItem(int index);
  public SinkBindingListFluent.ItemsNested<A> editFirstItem();
  public SinkBindingListFluent.ItemsNested<A> editLastItem();
  public SinkBindingListFluent.ItemsNested<A> editMatchingItem(Predicate<SinkBindingBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,SinkBindingFluent<SinkBindingListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
